@@ -68,7 +68,9 @@ class RegularForm(Form):
                 self._has_identifier == other._has_identifier
                 and self._form_key == other._form_key
                 and self._size == other._size
-                and _parameters_equal(self._parameters, other._parameters)
+                and _parameters_equal(
+                    self._parameters, other._parameters, only_array_record=True
+                )
                 and self._content == other._content
             )
         else:
@@ -81,7 +83,9 @@ class RegularForm(Form):
         elif isinstance(other, RegularForm):
             return (
                 self._size == other._size
-                and _parameters_equal(self._parameters, other._parameters)
+                and _parameters_equal(
+                    self._parameters, other._parameters, only_array_record=True
+                )
                 and self._content.generated_compatibility(other._content)
             )
 
@@ -141,6 +145,10 @@ class RegularForm(Form):
         else:
             return self._content.purelist_depth + 1
 
+    @property
+    def is_identity_like(self):
+        return False
+
     @property
     def minmax_depth(self):
         if self.parameter("__array__") in ("string", "bytestring"):
